@@ -45,9 +45,9 @@ if os.getenv("TREEBEARD_ENVIRONMENT"):
 
 
 if env == "development":
-    click.echo("WARNING: RUNNING IN LOCAL MODE")
+    click.echo("WARNING: RUNNING IN LOCAL MODE", err=True)
     url = "http://localhost:8080"
-    treebeard_web_url = "http://localhost:8000"
+    treebeard_web_url = "https://localhost:8000"
 else:
     url = "https://scheduler-cvee2224cq-ew.a.run.app"
     treebeard_web_url = "https://treebeard.io"
