@@ -10,6 +10,11 @@ from timeago import format as timeago_format  # type: ignore
 from treebeard.conf import signup_endpoint, treebeard_env, treebeard_web_url
 from treebeard.helper import set_credentials
 from treebeard.version import get_version
+import uuid
+import pprint
+
+pp = pprint.PrettyPrinter(indent=2)
+
 
 project_id = treebeard_env.project_id
 notebook_id = treebeard_env.notebook_id
@@ -21,9 +26,9 @@ warnings.filterwarnings(
 
 @click.command()
 @click.option("--email", prompt="Your email:")
-@click.option("--key", prompt="Your API key:")
-def configure(email: str, key: str):
-    """Set initial credentials"""
+def configure(email: str):
+    """Register with Treebeard services"""
+    key = str(uuid.uuid4())
     project_id = set_credentials(email, key, signup_endpoint)
     webbrowser.open_new_tab(
         f"{treebeard_web_url}/cli_signup?email={email}&api_key={key}&project_id={project_id}"
@@ -64,7 +69,20 @@ def version():
     click.echo(get_version())
 
 
-@click.command()
-def info():
-    """Shows treebeard credentials and project info"""
-    click.echo(treebeard_env)
+@click.group()
+def config():
+    """Shows Treebeard internal configuration"""
+
+
+@config.command()
+def list():
+    click.echo(pp.pformat(treebeard_env.dict()))
+
+
+@config.command()
+@click.argument("key", type=click.STRING)
+def get(key: str):
+    if key in treebeard_env.dict():
+        click.echo(treebeard_env.dict()[key])
+    else:
+        click.echo(f"There is no value for {key}")
